package org.openqa.selenium.devtools.v123.css.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * CSS container query rule descriptor.
 */
@org.openqa.selenium.Beta()
public class CSSContainerQuery {

    private final java.lang.String text;

    private final java.util.Optional<org.openqa.selenium.devtools.v123.css.model.SourceRange> range;

    private final java.util.Optional<org.openqa.selenium.devtools.v123.css.model.StyleSheetId> styleSheetId;

    private final java.util.Optional<java.lang.String> name;

    private final java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.PhysicalAxes> physicalAxes;

    private final java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.LogicalAxes> logicalAxes;

    public CSSContainerQuery(java.lang.String text, java.util.Optional<org.openqa.selenium.devtools.v123.css.model.SourceRange> range, java.util.Optional<org.openqa.selenium.devtools.v123.css.model.StyleSheetId> styleSheetId, java.util.Optional<java.lang.String> name, java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.PhysicalAxes> physicalAxes, java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.LogicalAxes> logicalAxes) {
        this.text = java.util.Objects.requireNonNull(text, "text is required");
        this.range = range;
        this.styleSheetId = styleSheetId;
        this.name = name;
        this.physicalAxes = physicalAxes;
        this.logicalAxes = logicalAxes;
    }

    /**
     * Container query text.
     */
    public java.lang.String getText() {
        return text;
    }

    /**
     * The associated rule header range in the enclosing stylesheet (if
     * available).
     */
    public java.util.Optional<org.openqa.selenium.devtools.v123.css.model.SourceRange> getRange() {
        return range;
    }

    /**
     * Identifier of the stylesheet containing this object (if exists).
     */
    public java.util.Optional<org.openqa.selenium.devtools.v123.css.model.StyleSheetId> getStyleSheetId() {
        return styleSheetId;
    }

    /**
     * Optional name for the container.
     */
    public java.util.Optional<java.lang.String> getName() {
        return name;
    }

    /**
     * Optional physical axes queried for the container.
     */
    public java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.PhysicalAxes> getPhysicalAxes() {
        return physicalAxes;
    }

    /**
     * Optional logical axes queried for the container.
     */
    public java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.LogicalAxes> getLogicalAxes() {
        return logicalAxes;
    }

    private static CSSContainerQuery fromJson(JsonInput input) {
        java.lang.String text = null;
        java.util.Optional<org.openqa.selenium.devtools.v123.css.model.SourceRange> range = java.util.Optional.empty();
        java.util.Optional<org.openqa.selenium.devtools.v123.css.model.StyleSheetId> styleSheetId = java.util.Optional.empty();
        java.util.Optional<java.lang.String> name = java.util.Optional.empty();
        java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.PhysicalAxes> physicalAxes = java.util.Optional.empty();
        java.util.Optional<org.openqa.selenium.devtools.v123.dom.model.LogicalAxes> logicalAxes = java.util.Optional.empty();
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "text":
                    text = input.nextString();
                    break;
                case "range":
                    range = java.util.Optional.ofNullable(input.read(org.openqa.selenium.devtools.v123.css.model.SourceRange.class));
                    break;
                case "styleSheetId":
                    styleSheetId = java.util.Optional.ofNullable(input.read(org.openqa.selenium.devtools.v123.css.model.StyleSheetId.class));
                    break;
                case "name":
                    name = java.util.Optional.ofNullable(input.nextString());
                    break;
                case "physicalAxes":
                    physicalAxes = java.util.Optional.ofNullable(input.read(org.openqa.selenium.devtools.v123.dom.model.PhysicalAxes.class));
                    break;
                case "logicalAxes":
                    logicalAxes = java.util.Optional.ofNullable(input.read(org.openqa.selenium.devtools.v123.dom.model.LogicalAxes.class));
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new CSSContainerQuery(text, range, styleSheetId, name, physicalAxes, logicalAxes);
    }
}
