package org.openqa.selenium.devtools.v85.storage;

import org.openqa.selenium.Beta;
import org.openqa.selenium.devtools.Command;
import org.openqa.selenium.devtools.Event;
import org.openqa.selenium.devtools.ConverterFunctions;
import java.util.Map;
import java.util.LinkedHashMap;
import org.openqa.selenium.json.JsonInput;

@Beta()
public class Storage {

    /**
     * Clears storage for origin.
     */
    public static Command<Void> clearDataForOrigin(java.lang.String origin, java.lang.String storageTypes) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        java.util.Objects.requireNonNull(storageTypes, "storageTypes is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        params.put("storageTypes", storageTypes);
        return new Command<>("Storage.clearDataForOrigin", Map.copyOf(params));
    }

    /**
     * Returns all browser cookies.
     */
    public static Command<java.util.List<org.openqa.selenium.devtools.v85.network.model.Cookie>> getCookies(java.util.Optional<org.openqa.selenium.devtools.v85.browser.model.BrowserContextID> browserContextId) {
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        browserContextId.ifPresent(p -> params.put("browserContextId", p));
        return new Command<>("Storage.getCookies", Map.copyOf(params), ConverterFunctions.map("cookies", input -> input.readArray(org.openqa.selenium.devtools.v85.network.model.Cookie.class)));
    }

    /**
     * Sets given cookies.
     */
    public static Command<Void> setCookies(java.util.List<org.openqa.selenium.devtools.v85.network.model.CookieParam> cookies, java.util.Optional<org.openqa.selenium.devtools.v85.browser.model.BrowserContextID> browserContextId) {
        java.util.Objects.requireNonNull(cookies, "cookies is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("cookies", cookies);
        browserContextId.ifPresent(p -> params.put("browserContextId", p));
        return new Command<>("Storage.setCookies", Map.copyOf(params));
    }

    /**
     * Clears cookies.
     */
    public static Command<Void> clearCookies(java.util.Optional<org.openqa.selenium.devtools.v85.browser.model.BrowserContextID> browserContextId) {
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        browserContextId.ifPresent(p -> params.put("browserContextId", p));
        return new Command<>("Storage.clearCookies", Map.copyOf(params));
    }

    public static class GetUsageAndQuotaResponse {

        private final java.lang.Number usage;

        private final java.lang.Number quota;

        private final java.util.List<org.openqa.selenium.devtools.v85.storage.model.UsageForType> usageBreakdown;

        public GetUsageAndQuotaResponse(java.lang.Number usage, java.lang.Number quota, java.util.List<org.openqa.selenium.devtools.v85.storage.model.UsageForType> usageBreakdown) {
            this.usage = java.util.Objects.requireNonNull(usage, "usage is required");
            this.quota = java.util.Objects.requireNonNull(quota, "quota is required");
            this.usageBreakdown = java.util.Objects.requireNonNull(usageBreakdown, "usageBreakdown is required");
        }

        /**
         * Storage usage (bytes).
         */
        public java.lang.Number getUsage() {
            return usage;
        }

        /**
         * Storage quota (bytes).
         */
        public java.lang.Number getQuota() {
            return quota;
        }

        /**
         * Storage usage per type (bytes).
         */
        public java.util.List<org.openqa.selenium.devtools.v85.storage.model.UsageForType> getUsageBreakdown() {
            return usageBreakdown;
        }

        private static GetUsageAndQuotaResponse fromJson(JsonInput input) {
            java.lang.Number usage = 0;
            java.lang.Number quota = 0;
            java.util.List<org.openqa.selenium.devtools.v85.storage.model.UsageForType> usageBreakdown = null;
            input.beginObject();
            while (input.hasNext()) {
                switch(input.nextName()) {
                    case "usage":
                        usage = input.nextNumber();
                        break;
                    case "quota":
                        quota = input.nextNumber();
                        break;
                    case "usageBreakdown":
                        usageBreakdown = input.readArray(org.openqa.selenium.devtools.v85.storage.model.UsageForType.class);
                        break;
                    default:
                        input.skipValue();
                        break;
                }
            }
            input.endObject();
            return new GetUsageAndQuotaResponse(usage, quota, usageBreakdown);
        }
    }

    /**
     * Returns usage and quota in bytes.
     */
    public static Command<org.openqa.selenium.devtools.v85.storage.Storage.GetUsageAndQuotaResponse> getUsageAndQuota(java.lang.String origin) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        return new Command<>("Storage.getUsageAndQuota", Map.copyOf(params), input -> input.read(org.openqa.selenium.devtools.v85.storage.Storage.GetUsageAndQuotaResponse.class));
    }

    /**
     * Registers origin to be notified when an update occurs to its cache storage list.
     */
    public static Command<Void> trackCacheStorageForOrigin(java.lang.String origin) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        return new Command<>("Storage.trackCacheStorageForOrigin", Map.copyOf(params));
    }

    /**
     * Registers origin to be notified when an update occurs to its IndexedDB.
     */
    public static Command<Void> trackIndexedDBForOrigin(java.lang.String origin) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        return new Command<>("Storage.trackIndexedDBForOrigin", Map.copyOf(params));
    }

    /**
     * Unregisters origin from receiving notifications for cache storage.
     */
    public static Command<Void> untrackCacheStorageForOrigin(java.lang.String origin) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        return new Command<>("Storage.untrackCacheStorageForOrigin", Map.copyOf(params));
    }

    /**
     * Unregisters origin from receiving notifications for IndexedDB.
     */
    public static Command<Void> untrackIndexedDBForOrigin(java.lang.String origin) {
        java.util.Objects.requireNonNull(origin, "origin is required");
        LinkedHashMap<String, Object> params = new LinkedHashMap<>();
        params.put("origin", origin);
        return new Command<>("Storage.untrackIndexedDBForOrigin", Map.copyOf(params));
    }

    public static Event<org.openqa.selenium.devtools.v85.storage.model.CacheStorageContentUpdated> cacheStorageContentUpdated() {
        return new Event<>("Storage.cacheStorageContentUpdated", input -> input.read(org.openqa.selenium.devtools.v85.storage.model.CacheStorageContentUpdated.class));
    }

    public static Event<java.lang.String> cacheStorageListUpdated() {
        return new Event<>("Storage.cacheStorageListUpdated", ConverterFunctions.map("origin", java.lang.String.class));
    }

    public static Event<org.openqa.selenium.devtools.v85.storage.model.IndexedDBContentUpdated> indexedDBContentUpdated() {
        return new Event<>("Storage.indexedDBContentUpdated", input -> input.read(org.openqa.selenium.devtools.v85.storage.model.IndexedDBContentUpdated.class));
    }

    public static Event<java.lang.String> indexedDBListUpdated() {
        return new Event<>("Storage.indexedDBListUpdated", ConverterFunctions.map("origin", java.lang.String.class));
    }
}
